Plot for assessing agreement between two methods of clinical measurement
bland.altman.ade(x, y, data=NULL, ltext=TRUE, main="Bland-Altman Plot",
xlab=NULL, ylab=NULL, xlim=NULL, ylim=NULL,
lwd=2, cex=1, pch=16, lty=c(1,2,2), xticks=NULL, yticks=NULL,
col=NULL, tcol=NULL, bgcol=NULL, lcol=c(4,2,2), alpha=NULL,
fitline=1, wall=0, v=NULL, h=NULL, span=0.75)
a numeric vector of first mesurement
a string with the name of first mesurement in the data.frame
a numeric vector of second mesurement
a string with the name of second mesurement in the data.frame
data.frame if used strings for (x,y)
logical asking whether to draw labels for the lines
a string vector with the labels for the lines
an overall title for the plot
a title for the x axis
a title for the y axis
the x limits (x1, x2) of the plot
the y limits (y1, y2) of the plot
the line width
character (or symbol) expansion: a numerical value
plotting "character", i.e., symbol to use. This can either be a single character or an integer code for one of a set of graphics symbols.
the line type, a vector is possible
the number of ticks on the x axis or a vector of exact ticks
the number of ticks on the y axis or a vector of exact ticks
color of the points
color of the text in whole plot
the background color for plot dekoration
color for the lines in plot, a vector of colors is possible
a parameter in [0, 1] for semi-transparency of points
a number between 0 and 3 to fit:
0. not fit
1. a lm regression line
2. a loess local regression line
3. a pylinomial regression line
a number between 0 and 6 for selection the dekoration style of the plot.
the x-value(s) for vertical line(s).
the y-value(s) for horizontal line(s).
the span parameter for lowess curve fit (only if fitline=2)
It is only a Wrapper function for scatter.ade. Ploting the Difference against the mean for both variables.
scatter.ade
x<-rnorm(1000, 0, 3)
y<-x+rnorm(1000, 1, 0.5)
bland.altman.ade(x, y, wall=2)
Run the code above in your browser using DataLab