Draw points and a line between the points
curves.ade(x, y=NULL, group=NULL, data=NULL, vnames=NULL,
main=NULL, xlab=NULL, ylab=NULL, legendon="topright",
xlim=NULL, ylim=NULL, lwd=1, lwd2=1, cex=1, pch=16,
lty=1, lty2=2, col=NULL, xticks=NULL, yticks=NULL,
tcol=NULL, bgcol=NULL, alpha=NULL, fitline=0,
wall=0, v=NULL, h=NULL, diag=F, points=T)
a numeric vector of x coordinates for the points
a string with the name of the variable in the data.frame
a formula y~x or y~x+group
a numeric vector of y coordinates for the points
a string with the name of the variable in the data.frame
a formula y~x or y~x+group
a factor to group the points
a character string with the name of the group variable in the data.frame
data.frame if used strings for (x,y,group)
a vector of character strings with the names of groups in the legend
an overall title for the plot
a title for the x axis
a title for the y axis
a single keyword from:
"bottomright"
"bottom"
"bottomleft"
"left"
"topleft"
"top"
"topright"
"right"
"center"
This places the legend on the inside of the plot frame at the given location.
the x limits (x1, x2) of the plot
the y limits (y1, y2) of the plot
line width for the lines
line width for the fited lines
character (or symbol) expansion: a numerical value
plotting "character", i.e., symbol to use. This can either be a single character or an integer code for one of a set of graphics symbols.
the line types
the line type for fited lines
a vector of colors for the lines of each group
the number of ticks on the x axis or a vector of exact ticks
the number of ticks on the y axis or a vector of exact ticks
color of the text in whole plot
the background color for plot dekoration
a parameter in [0, 1] for semi-transparency of lines and points
a number between 0 and 3 to fit:
0. not fit
1. a lm regression line
2. a loess local regression line
3. a pylinomial regression line
a number between 0 and 6 for selection the dekoration style of the plot.
the x-value(s) for vertical line(s).
the y-value(s) for horizontal line(s).
logical asking whether to plot a diagonal line
logical asking whether to draw points
It is only a wrapper function for scatter.ade.
scatter.ade
x<- -100:100
curves.ade(x, x^2, points=FALSE)
Run the code above in your browser using DataLab