Learn R Programming

epade (version 0.2.2)

bland.altman.ade: Bland-Altman plot

Description

Plot for assessing agreement between two methods of clinical measurement

Usage

bland.altman.ade(x, y, data=NULL, ltext=TRUE, main="Bland-Altman Plot",
                 xlab=NULL, ylab=NULL, xlim=NULL, ylim=NULL,
                 lwd=2, cex=1, pch=16, lty=c(1,2,2), xticks=NULL, yticks=NULL,
                 col=NULL, tcol=NULL, bgcol=NULL, lcol=c(4,2,2), alpha=NULL,
                 fitline=1, wall=0, v=NULL, h=NULL, span=0.75)

Arguments

x
  • a numeric vector of first mesurement
a string with the name of first mesurement in the data.frame

item

  • y
  • a string with the name of second mesurement in the data.frame
  • data
  • ltext
  • a string vector with the labels for the lines
  • main
  • xlab
  • ylab
  • xlim
  • ylim
  • lwd
  • cex
  • pch
  • lty
  • xticks
  • yticks
  • col
  • tcol
  • bgcol
  • lcol
  • alpha
  • fitline
  • 1. a lm regression line
  • 2. a loess local regression line
  • 3. a pylinomial regression line
  • wall
  • v
  • h
  • span

itemize

  • 0. not fit

Details

It is only a Wrapper function for scatter.ade. Ploting the Difference against the mean for both variables.

See Also

scatter.ade

Examples

Run this code
x<-rnorm(1000, 0, 3)
y<-x+rnorm(1000, 1, 0.5)
bland.altman.ade(x, y, wall=2)

Run the code above in your browser using DataLab